==> jps-build-193.5233.102-sources.jar: org/jetbrains/jps/incremental/storage/ProjectStamps.java <==
/*
 * Copyright 2000-2012 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.jps.incremental.storage;

import com.intellij.openapi.diagnostic.Logger;
import com.intellij.openapi.util.io.FileUtil;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.jps.incremental.relativizer.PathRelativizerService;

import java.io.File;
import java.io.IOException;

/**
 * @author Eugene Zhuravlev
 */
public class ProjectStamps {
  public static final boolean PORTABLE_CACHES = Boolean.getBoolean("org.jetbrains.jps.portable.caches");

  private static final Logger LOG = Logger.getInstance("#org.jetbrains.jps.incremental.storage.ProjectStamps");

  private final TimestampStorage<? extends StampsStorage.Stamp> myStampsStorage;

  public ProjectStamps(File dataStorageRoot,
                       BuildTargetsState targetsState,
                       PathRelativizerService relativizer) throws IOException {
    myStampsStorage = PORTABLE_CACHES
                      ? new FileStampStorage(dataStorageRoot, relativizer, targetsState)
                      : new FileTimestampStorage(dataStorageRoot, targetsState);
  }

  /**
   * @deprecated use {@link #getStampStorage()} instead
   */
  @Deprecated
  @ApiStatus.ScheduledForRemoval(inVersion = "2020.1")
  public TimestampStorage<? extends StampsStorage.Stamp> getStorage() {
    return myStampsStorage;
  }

  public StampsStorage<? extends StampsStorage.Stamp> getStampStorage() {
    return myStampsStorage;
  }

  public void clean() {
    myStampsStorage.wipe();
  }

  public void close() {
    try {
      myStampsStorage.close();
    }
    catch (IOException e) {
      LOG.error(e);
      FileUtil.delete(myStampsStorage.getStorageRoot());
    }
  }
}

==> jps-build-201.8743.12-sources.jar: org/jetbrains/jps/incremental/storage/ProjectStamps.java <==
/*
 * Copyright 2000-2012 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.jps.incremental.storage;

import com.intellij.openapi.diagnostic.Logger;
import com.intellij.openapi.util.io.FileUtil;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.jps.incremental.relativizer.PathRelativizerService;

import java.io.File;
import java.io.IOException;

/**
 * @author Eugene Zhuravlev
 */
public class ProjectStamps {
  public static final boolean PORTABLE_CACHES = Boolean.getBoolean("org.jetbrains.jps.portable.caches");

  private static final Logger LOG = Logger.getInstance(ProjectStamps.class);

  private final TimestampStorage<? extends StampsStorage.Stamp> myStampsStorage;

  public ProjectStamps(File dataStorageRoot,
                       BuildTargetsState targetsState,
                       PathRelativizerService relativizer) throws IOException {
    myStampsStorage = PORTABLE_CACHES
                      ? new FileStampStorage(dataStorageRoot, relativizer, targetsState)
                      : new FileTimestampStorage(dataStorageRoot, targetsState);
  }

  /**
   * @deprecated use {@link #getStampStorage()} instead
   */
  @Deprecated
  @ApiStatus.ScheduledForRemoval(inVersion = "2020.1")
  public TimestampStorage<? extends StampsStorage.Stamp> getStorage() {
    return myStampsStorage;
  }

  public StampsStorage<? extends StampsStorage.Stamp> getStampStorage() {
    return myStampsStorage;
  }

  public void clean() {
    myStampsStorage.wipe();
  }

  public void close() {
    try {
      myStampsStorage.close();
    }
    catch (IOException e) {
      LOG.error(e);
      FileUtil.delete(myStampsStorage.getStorageRoot());
    }
  }
}
